@@ -7,9 +7,10 @@
 #' 
 #' @seealso \code{\link{babble}}
 #' 
+#' @useDynLib ngram R_ngram_get_seed
 #' @keywords Utility
 #' @export
-getseed <- function()
+getseed = function()
 {
   .Call(R_ngram_get_seed, PACKAGE="ngram")
 }
